@@ -15,7 +15,7 @@ use statsig_rust::output_logger::OutputLogProvider;
 use statsig_rust::statsig_options::DEFAULT_INIT_TIMEOUT_MS;
 use statsig_rust::{log_w, ConfigCompressionMode, PersistentStorage, SpecAdapterConfig};
 use statsig_rust::{output_logger::LogLevel, ObservabilityClient, StatsigOptions};
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
 use std::sync::{Arc, Weak};
 
 const TAG: &str = stringify!(StatsigOptionsPy);
@@ -160,6 +160,8 @@ pub struct StatsigOptionsPy {
     pub use_third_party_ua_parser: Option<bool>,
     #[pyo3(get, set)]
     pub disable_disk_access: Option<bool>,
+    #[pyo3(get, set)]
+    pub experimental_flags: Option<HashSet<String>>,
 }
 
 #[gen_stub_pymethods]
@@ -195,6 +197,7 @@ impl StatsigOptionsPy {
         spec_adapter_configs=None,
         use_third_party_ua_parser=None,
         disable_disk_access=None,
+        experimental_flags=None,
     ))]
     #[allow(clippy::too_many_arguments)]
     pub fn new(
@@ -226,6 +229,7 @@ impl StatsigOptionsPy {
         spec_adapter_configs: Option<Py<PyList>>,
         use_third_party_ua_parser: Option<bool>,
         disable_disk_access: Option<bool>,
+        experimental_flags: Option<HashSet<String>>,
     ) -> Self {
         Self {
             specs_url,
@@ -256,6 +260,7 @@ impl StatsigOptionsPy {
             spec_adapter_configs,
             use_third_party_ua_parser,
             disable_disk_access,
+            experimental_flags,
         }
     }
 }
@@ -370,8 +375,10 @@ fn create_inner_statsig_options(
                     .unwrap_or_default(),
             ) as Arc<dyn OutputLogProvider>
         }),
+        console_capture_options: None,
         use_third_party_ua_parser: opts.use_third_party_ua_parser,
         disable_disk_access: opts.disable_disk_access,
+        experimental_flags: opts.experimental_flags,
     }
 }
 
