@@ -9,10 +9,13 @@ use crate::interned_string::InternedString;
 use crate::specs_response::spec_types::{Rule, Spec, SpecsResponseFull};
 use crate::user::StatsigUserInternal;
 use crate::StatsigErr::StackOverflowError;
-use crate::{OverrideAdapter, StatsigErr};
+use crate::{OverrideAdapter, Statsig, StatsigErr};
 
 const MAX_RECURSIVE_DEPTH: u16 = 300;
 
+// (gate_name, (bool_value, rule_id))
+type NestedGateMemo = HashMap<InternedString, (bool, Option<InternedString>)>;
+
 pub enum IdListResolution<'a> {
     MapLookup(&'a HashMap<String, IdList>),
     Callback(&'a dyn Fn(&str, &str) -> bool),
@@ -23,15 +26,18 @@ pub struct EvaluatorContext<'a> {
     pub specs_data: &'a SpecsResponseFull,
     pub id_list_resolver: IdListResolution<'a>,
     pub hashing: &'a HashUtil,
-    pub result: EvaluatorResult<'a>,
+    pub result: EvaluatorResult,
     pub nested_count: u16,
     pub app_id: Option<&'a DynamicValue>,
     pub override_adapter: Option<&'a Arc<dyn OverrideAdapter>>,
-    pub nested_gate_memo: HashMap<&'a str, (bool, Option<&'a InternedString>)>,
+    pub nested_gate_memo: NestedGateMemo,
     pub should_user_third_party_parser: bool,
+    pub statsig: Option<&'a Statsig>,
+    pub disable_exposure_logging: bool,
 }
 
 impl<'a> EvaluatorContext<'a> {
+    #[allow(clippy::too_many_arguments)]
     pub fn new(
         user: &'a StatsigUserInternal,
         specs_data: &'a SpecsResponseFull,
@@ -40,6 +46,8 @@ impl<'a> EvaluatorContext<'a> {
         app_id: Option<&'a DynamicValue>,
         override_adapter: Option<&'a Arc<dyn OverrideAdapter>>,
         should_user_third_party_parser: bool,
+        statsig: Option<&'a Statsig>,
+        disable_exposure_logging: bool,
     ) -> Self {
         let result = EvaluatorResult::default();
 
@@ -54,6 +62,8 @@ impl<'a> EvaluatorContext<'a> {
             nested_count: 0,
             nested_gate_memo: HashMap::new(),
             should_user_third_party_parser,
+            statsig,
+            disable_exposure_logging,
         }
     }
 
