@@ -7,6 +7,7 @@ use crate::{
         statsig_event::StatsigEvent,
         statsig_event_internal::{StatsigEventInternal, CONFIG_EXPOSURE_EVENT_NAME},
     },
+    interned_string::InternedString,
     statsig_types::Experiment,
     user::{StatsigUserInternal, StatsigUserLoggable},
     EvaluationDetails, SecondaryExposure,
@@ -86,7 +87,7 @@ pub struct QueuedExperimentExposureEvent {
     pub version: Option<u32>,
     pub exposure_trigger: ExposureTrigger,
     pub sampling_decision: EvtSamplingDecision,
-    pub override_config_name: Option<String>,
+    pub override_config_name: Option<InternedString>,
     pub exposure_time: u64,
 }
 
@@ -105,7 +106,10 @@ impl QueuedExperimentExposureEvent {
         }
 
         if let Some(override_config_name) = self.override_config_name {
-            metadata.insert("overrideConfigName".into(), override_config_name);
+            metadata.insert(
+                "overrideConfigName".into(),
+                override_config_name.unperformant_to_string(),
+            );
         }
 
         let statsig_metadata = get_statsig_metadata_with_sampling_decision(self.sampling_decision);
