@@ -7,7 +7,7 @@ use crate::{
     },
     hashing::HashUtil,
     interned_string::InternedString,
-    specs_response::{spec_directory::SpecDirectory, spec_types::Spec},
+    specs_response::{spec_types::Spec, specs_hash_map::SpecsHashMap},
     ClientInitResponseOptions, HashAlgorithm, SecondaryExposure, StatsigErr,
 };
 use std::collections::{HashMap, HashSet};
@@ -16,15 +16,14 @@ pub(crate) fn gcir_process_iter<T>(
     context: &mut EvaluatorContext,
     options: &ClientInitResponseOptions,
     sec_expo_hash_memo: &mut HashMap<InternedString, InternedString>,
-    spec_directory: &SpecDirectory,
+    specs_map: &SpecsHashMap,
     get_spec_type: impl Fn(&Spec) -> SpecType,
     mut evaluation_factory: impl FnMut(&str, &str, &mut EvaluatorContext) -> T,
 ) -> Result<HashMap<String, T>, StatsigErr> {
     let mut results = HashMap::new();
 
-    for spec_addy in spec_directory.specs.values() {
-        let spec = &spec_addy.spec;
-        let name = &spec_addy.name;
+    for (name, spec_ptr) in specs_map.iter() {
+        let spec = spec_ptr.inner.as_ref();
 
         if spec.entity == "segment" || spec.entity == "holdout" {
             continue;
@@ -41,11 +40,20 @@ pub(crate) fn gcir_process_iter<T>(
         context.reset_result();
 
         let spec_type = get_spec_type(spec);
-        Evaluator::evaluate(context, spec_addy.name.as_str(), &spec_type)?;
+        Evaluator::evaluate(context, name.as_str(), &spec_type)?;
+
+        if options.remove_default_value_gates.unwrap_or(false)
+            && spec.entity == "feature_gate"
+            && context.result.rule_id.as_deref() == Some("default")
+            && !context.result.bool_value
+            && context.result.secondary_exposures.is_empty()
+        {
+            continue;
+        }
 
         let hashed_name = context
             .hashing
-            .hash(spec_addy.name.as_str(), options.get_hash_algorithm());
+            .hash(name.as_str(), options.get_hash_algorithm());
         hash_secondary_exposures(
             &mut context.result,
             context.hashing,
@@ -54,6 +62,7 @@ pub(crate) fn gcir_process_iter<T>(
         );
 
         let eval = evaluation_factory(&spec.entity, &hashed_name, context);
+
         results.insert(hashed_name, eval);
     }
 
