@@ -148,18 +148,24 @@ impl NetworkClient {
                 }
             };
 
+            let content_type = response
+                .data
+                .as_ref()
+                .and_then(|data| data.get_header_ref("content-type"));
+
             log_d!(
                 TAG,
-                "Response ({}): {:?}",
+                "Response url({}) status({:?}) content-type({:?})",
                 &request_args.url,
-                response.status_code
+                response.status_code,
+                content_type
             );
 
             let status = response.status_code;
             let sdk_region_str = response
-                .headers
+                .data
                 .as_ref()
-                .and_then(|h| h.get("x-statsig-region"));
+                .and_then(|data| data.get_header_ref("x-statsig-region").cloned());
             let success = (200..300).contains(&status.unwrap_or(0));
 
             let error_message = response
