@@ -1,29 +1,33 @@
-use crate::data_store_interface::{get_data_adapter_dcs_key, DataStoreTrait};
-use crate::global_configs::GlobalConfigs;
-use crate::id_lists_adapter::{IdList, IdListsUpdateListener};
-use crate::networking::ResponseData;
-use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
-use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
-use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
-use crate::sdk_event_emitter::{SdkEvent, SdkEventEmitter};
-use crate::specs_response::spec_types::{SpecsResponseFull, SpecsResponseNoUpdates};
-use crate::utils::maybe_trim_malloc;
-use crate::{
-    log_d, log_e, log_error_to_statsig_and_console, SpecsInfo, SpecsSource, SpecsUpdate,
-    SpecsUpdateListener, StatsigErr, StatsigRuntime,
-};
 use chrono::Utc;
 use parking_lot::RwLock;
 use std::collections::HashMap;
 use std::sync::Arc;
 use std::time::Duration;
 
+use crate::data_store_interface::{get_data_adapter_dcs_key, DataStoreTrait};
+use crate::evaluation::evaluator::SpecType;
+use crate::global_configs::GlobalConfigs;
+use crate::id_lists_adapter::{IdList, IdListsUpdateListener};
+use crate::interned_string::InternedString;
+use crate::networking::ResponseData;
+use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
+use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
+use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
+use crate::sdk_event_emitter::{SdkEvent, SdkEventEmitter};
+use crate::specs_response::proto_specs::deserialize_protobuf;
+use crate::specs_response::spec_types::{SpecsResponseFull, SpecsResponseNoUpdates};
+use crate::utils::maybe_trim_malloc;
+use crate::{
+    log_d, log_e, log_error_to_statsig_and_console, read_lock_or_else, SpecsInfo, SpecsSource,
+    SpecsUpdate, SpecsUpdateListener, StatsigErr, StatsigOptions, StatsigRuntime,
+};
+
 pub struct SpecStoreData {
     pub source: SpecsSource,
     pub source_api: Option<String>,
     pub time_received_at: Option<u64>,
     pub values: SpecsResponseFull,
-    pub next_values: Option<SpecsResponseFull>,
+    pub next_values: SpecsResponseFull,
     pub id_lists: HashMap<String, IdList>,
 }
 
@@ -38,6 +42,7 @@ pub struct SpecStore {
     ops_stats: Arc<OpsStatsForInstance>,
     global_configs: Arc<GlobalConfigs>,
     event_emitter: Arc<SdkEventEmitter>,
+    enable_proto_spec_support: bool,
 }
 
 impl SpecStore {
@@ -47,13 +52,22 @@ impl SpecStore {
         hashed_sdk_key: String,
         statsig_runtime: Arc<StatsigRuntime>,
         event_emitter: Arc<SdkEventEmitter>,
-        data_store: Option<Arc<dyn DataStoreTrait>>,
+        options: Option<&StatsigOptions>,
     ) -> SpecStore {
+        let mut data_store = None;
+        if let Some(options) = options {
+            data_store = options.data_store.clone();
+        }
+
+        let enable_proto_spec_support = options
+            .and_then(|opts| opts.experimental_flags.as_ref())
+            .is_some_and(|flags| flags.contains("enable_proto_spec_support"));
+
         SpecStore {
             hashed_sdk_key,
             data: Arc::new(RwLock::new(SpecStoreData {
                 values: SpecsResponseFull::default(),
-                next_values: Some(SpecsResponseFull::default()),
+                next_values: SpecsResponseFull::default(),
                 time_received_at: None,
                 source: SpecsSource::Uninitialized,
                 source_api: None,
@@ -64,6 +78,7 @@ impl SpecStore {
             statsig_runtime,
             ops_stats: OPS_STATS.get_for_instance(sdk_key),
             global_configs: GlobalConfigs::get_instance(sdk_key),
+            enable_proto_spec_support,
         }
     }
 
@@ -91,10 +106,93 @@ impl SpecStore {
         serde_json::from_str::<SpecsResponseFull>(&json).ok()
     }
 
+    pub fn get_fields_used_for_entity(
+        &self,
+        entity_name: &str,
+        entity_type: SpecType,
+    ) -> Vec<String> {
+        let data = read_lock_or_else!(self.data, {
+            log_error_to_statsig_and_console!(
+                &self.ops_stats,
+                TAG,
+                StatsigErr::LockFailure(
+                    "Failed to acquire read lock for spec store data".to_string()
+                )
+            );
+            return vec![];
+        });
+
+        let entities = match entity_type {
+            SpecType::Gate => &data.values.feature_gates,
+            SpecType::DynamicConfig | SpecType::Experiment => &data.values.dynamic_configs,
+            SpecType::Layer => &data.values.layer_configs,
+        };
+
+        let entity_name = InternedString::from_str_ref(entity_name);
+        let entity = entities.get(&entity_name);
+
+        match entity {
+            Some(entity) => match &entity.inner.fields_used {
+                Some(fields) => fields.iter().map(|f| f.unperformant_to_string()).collect(),
+                None => vec![],
+            },
+            None => vec![],
+        }
+    }
+
+    pub fn unperformant_keys_entity_filter(
+        &self,
+        top_level_key: &str,
+        entity_type: &str,
+    ) -> Vec<String> {
+        let data = read_lock_or_else!(self.data, {
+            log_error_to_statsig_and_console!(
+                &self.ops_stats,
+                TAG,
+                StatsigErr::LockFailure(
+                    "Failed to acquire read lock for spec store data".to_string()
+                )
+            );
+            return vec![];
+        });
+
+        if top_level_key == "param_stores" {
+            match &data.values.param_stores {
+                Some(param_stores) => {
+                    return param_stores
+                        .keys()
+                        .map(|k| k.unperformant_to_string())
+                        .collect()
+                }
+                None => return vec![],
+            }
+        }
+
+        let values = match top_level_key {
+            "feature_gates" => &data.values.feature_gates,
+            "dynamic_configs" => &data.values.dynamic_configs,
+            "layer_configs" => &data.values.layer_configs,
+            _ => {
+                log_e!(TAG, "Invalid top level key: {}", top_level_key);
+                return vec![];
+            }
+        };
+
+        if entity_type == "*" {
+            return values.keys().map(|k| k.unperformant_to_string()).collect();
+        }
+
+        values
+            .iter()
+            .filter(|(_, v)| v.inner.entity == entity_type)
+            .map(|(k, _)| k.unperformant_to_string())
+            .collect()
+    }
+
     pub fn set_values(&self, specs_update: SpecsUpdate) -> Result<(), StatsigErr> {
         let mut specs_update = specs_update;
-        let mut next_values = match self.data.try_write_for(Duration::from_secs(5)) {
-            Some(mut data) => data.next_values.take().unwrap_or_default(),
+        let mut locked_data = match self.data.try_write_for(Duration::from_secs(5)) {
+            Some(data) => data,
             None => {
                 log_e!(TAG, "Failed to acquire write lock: Failed to lock data");
                 return Err(StatsigErr::LockFailure(
@@ -103,7 +201,7 @@ impl SpecStore {
             }
         };
 
-        match self.parse_specs_response(&mut specs_update, &mut next_values) {
+        match self.parse_specs_response(&mut specs_update, &mut locked_data) {
             Ok(ParseResult::HasUpdates) => (),
             Ok(ParseResult::NoUpdates) => {
                 self.ops_stats_log_no_update(specs_update.source, specs_update.source_api);
@@ -114,15 +212,15 @@ impl SpecStore {
             }
         };
 
-        if self.are_current_values_newer(&next_values) {
+        if self.are_current_values_newer(&locked_data) {
             return Ok(());
         }
 
-        self.try_update_global_configs(&next_values);
+        self.try_update_global_configs(&locked_data.next_values);
 
         let now = Utc::now().timestamp_millis() as u64;
         let (prev_source, prev_lcut, curr_values_time) = self.swap_current_with_next(
-            next_values,
+            &mut locked_data,
             &specs_update,
             now,
             specs_update.source_api.clone(),
@@ -152,11 +250,30 @@ impl SpecStore {
     fn parse_specs_response(
         &self,
         values: &mut SpecsUpdate,
-        next_values: &mut SpecsResponseFull,
+        spec_store_data: &mut SpecStoreData,
     ) -> Result<ParseResult, StatsigErr> {
-        let parse_result = values.data.deserialize_in_place(next_values);
+        spec_store_data.next_values.reset();
 
-        if parse_result.is_ok() && next_values.has_updates {
+        let content_type = values.data.get_header_ref("content-type");
+
+        let use_protobuf = self.enable_proto_spec_support
+            && content_type
+                .map(|s| s.as_str().contains("application/octet-stream"))
+                .unwrap_or(false);
+
+        let parse_result = if use_protobuf {
+            deserialize_protobuf(
+                &spec_store_data.values,
+                &mut spec_store_data.next_values,
+                &mut values.data,
+            )
+        } else {
+            values
+                .data
+                .deserialize_in_place(&mut spec_store_data.next_values)
+        };
+
+        if parse_result.is_ok() && spec_store_data.next_values.has_updates {
             return Ok(ParseResult::HasUpdates);
         }
 
@@ -177,34 +294,23 @@ impl SpecStore {
 
     fn swap_current_with_next(
         &self,
-        next_values: SpecsResponseFull,
+        data: &mut SpecStoreData,
         specs_update: &SpecsUpdate,
         now: u64,
         source_api: Option<String>,
     ) -> Result<(SpecsSource, u64, u64), StatsigErr> {
-        match self.data.try_write_for(Duration::from_secs(5)) {
-            Some(mut data) => {
-                let prev_source = std::mem::replace(&mut data.source, specs_update.source.clone());
-                let prev_lcut = data.values.time;
+        let prev_source = std::mem::replace(&mut data.source, specs_update.source.clone());
+        let prev_lcut = data.values.time;
 
-                let mut temp = next_values;
-                std::mem::swap(&mut data.values, &mut temp);
-                data.next_values = Some(temp);
+        std::mem::swap(&mut data.values, &mut data.next_values);
 
-                data.time_received_at = Some(now);
-                data.source_api = source_api;
+        data.time_received_at = Some(now);
+        data.source_api = source_api;
+        data.next_values.reset();
 
-                self.emit_specs_updated_sdk_event(&data.source, &data.source_api, &data.values);
+        self.emit_specs_updated_sdk_event(&data.source, &data.source_api, &data.values);
 
-                Ok((prev_source, prev_lcut, data.values.time))
-            }
-            None => {
-                log_e!(TAG, "Failed to acquire write lock: Failed to lock data");
-                Err(StatsigErr::LockFailure(
-                    "Failed to acquire write lock: Failed to lock data".to_string(),
-                ))
-            }
-        }
+        Ok((prev_source, prev_lcut, data.values.time))
     }
 
     fn emit_specs_updated_sdk_event(
@@ -244,7 +350,7 @@ impl SpecStore {
         prev_source: &SpecsSource,
         source_api: Option<String>,
     ) {
-        let delay = Utc::now().timestamp_millis() as u64 - lcut;
+        let delay = (Utc::now().timestamp_millis() as u64).saturating_sub(lcut);
         log_d!(TAG, "Updated ({:?})", source);
 
         if *prev_source == SpecsSource::Uninitialized || *prev_source == SpecsSource::Loading {
@@ -323,16 +429,9 @@ impl SpecStore {
         }
     }
 
-    fn are_current_values_newer(&self, next_values: &SpecsResponseFull) -> bool {
-        let data = match self.data.try_read_for(Duration::from_secs(5)) {
-            Some(data) => data,
-            None => {
-                log_e!(TAG, "Failed to acquire read lock: Failed to lock data");
-                return false;
-            }
-        };
-
+    fn are_current_values_newer(&self, data: &SpecStoreData) -> bool {
         let curr_values = &data.values;
+        let next_values = &data.next_values;
         let curr_checksum = curr_values.checksum.as_deref().unwrap_or_default();
         let new_checksum = next_values.checksum.as_deref().unwrap_or_default();
 
