@@ -1,3 +1,8 @@
+use crate::console_capture::console_capture_handler::ConsoleCaptureHandler;
+use crate::console_capture::console_capture_instances::{
+    ConsoleCaptureInstance, CONSOLE_CAPTURE_REGISTRY,
+};
+use crate::console_capture::console_log_line_levels::StatsigLogLineLevel;
 use crate::evaluation::cmab_evaluator::{get_cmab_ranked_list, CMABRankedGroup};
 use crate::evaluation::country_lookup::CountryLookup;
 use crate::evaluation::dynamic_value::DynamicValue;
@@ -13,10 +18,11 @@ use crate::evaluation::user_agent_parsing::{ParsedUserAgentValue, UserAgentParse
 use crate::event_logging::event_logger::{EventLogger, ExposureTrigger};
 use crate::event_logging::event_queue::queued_config_expo::EnqueueConfigExpoOp;
 use crate::event_logging::event_queue::queued_experiment_expo::EnqueueExperimentExpoOp;
+use crate::event_logging::event_queue::queued_expo::EnqueueExposureOp;
 use crate::event_logging::event_queue::queued_gate_expo::EnqueueGateExpoOp;
 use crate::event_logging::event_queue::queued_layer_param_expo::EnqueueLayerParamExpoOp;
 use crate::event_logging::event_queue::queued_passthrough::EnqueuePassthroughOp;
-use crate::event_logging::statsig_event_internal::{StatsigEventInternal, StatsigLogLineLevel};
+use crate::event_logging::statsig_event_internal::StatsigEventInternal;
 use crate::event_logging_adapter::EventLoggingAdapter;
 use crate::event_logging_adapter::StatsigHttpEventLoggingAdapter;
 use crate::gcir::gcir_formatter::GCIRFormatter;
@@ -25,6 +31,8 @@ use crate::hashing::HashUtil;
 use crate::initialize_evaluations_response::InitializeEvaluationsResponse;
 use crate::initialize_response::InitializeResponse;
 use crate::initialize_v2_response::InitializeV2Response;
+use crate::interned_string::InternedString;
+use crate::observability::console_capture_observer::ConsoleCaptureObserver;
 use crate::observability::diagnostics_observer::DiagnosticsObserver;
 use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
@@ -97,8 +105,10 @@ pub struct Statsig {
     statsig_environment: Option<HashMap<String, DynamicValue>>,
     fallback_environment: Mutex<Option<HashMap<String, DynamicValue>>>,
     ops_stats: Arc<OpsStatsForInstance>,
+    console_capture: Arc<ConsoleCaptureInstance>,
     error_observer: Arc<dyn OpsStatsEventObserver>,
     diagnostics_observer: Arc<dyn OpsStatsEventObserver>,
+    console_capture_observer: Arc<dyn OpsStatsEventObserver>,
     background_tasks_started: Arc<AtomicBool>,
     persistent_values_manager: Option<Arc<PersistentValuesManager>>,
     initialize_details: Mutex<InitializeDetails>,
@@ -110,7 +120,9 @@ pub struct StatsigContext {
     pub local_override_adapter: Option<Arc<dyn OverrideAdapter>>,
     pub error_observer: Arc<dyn OpsStatsEventObserver>,
     pub diagnostics_observer: Arc<dyn OpsStatsEventObserver>,
+    pub console_capture_observer: Arc<dyn OpsStatsEventObserver>,
     pub spec_store: Arc<SpecStore>,
+    pub console_capture: Arc<ConsoleCaptureInstance>,
 }
 
 impl Drop for Statsig {
@@ -159,12 +171,16 @@ impl Statsig {
             Arc::new(DiagnosticsObserver::new(diagnostics));
         let error_observer: Arc<dyn OpsStatsEventObserver> =
             Arc::new(SDKErrorsObserver::new(sdk_key, &options));
+        let console_capture = Arc::new(ConsoleCaptureHandler::new(event_logger.clone()));
+        let console_capture_observer: Arc<dyn OpsStatsEventObserver> =
+            Arc::new(ConsoleCaptureObserver::new(console_capture));
 
         let ops_stats = setup_ops_stats(
             sdk_key,
             statsig_runtime.clone(),
             &error_observer,
             &diagnostics_observer,
+            &console_capture_observer,
             &options.observability_client,
         );
 
@@ -175,7 +191,7 @@ impl Statsig {
             hashing.sha256(sdk_key),
             statsig_runtime.clone(),
             event_emitter.clone(),
-            options.data_store.clone(),
+            Some(&options),
         ));
 
         let environment = options
@@ -191,6 +207,9 @@ impl Statsig {
 
         StatsigMetadata::update_service_name(options.service_name.clone());
 
+        let console_capture =
+            CONSOLE_CAPTURE_REGISTRY.get_for_instance(sdk_key, &options, &environment);
+
         Statsig {
             sdk_key: sdk_key.to_string(),
             options,
@@ -205,8 +224,10 @@ impl Statsig {
             id_lists_adapter,
             statsig_runtime,
             ops_stats,
+            console_capture,
             error_observer,
             diagnostics_observer,
+            console_capture_observer,
             background_tasks_started: Arc::new(AtomicBool::new(false)),
             persistent_values_manager,
             initialize_details: Mutex::new(InitializeDetails::default()),
@@ -351,7 +372,9 @@ impl Statsig {
             local_override_adapter: self.override_adapter.clone(),
             error_observer: self.error_observer.clone(),
             diagnostics_observer: self.diagnostics_observer.clone(),
+            console_capture_observer: self.console_capture_observer.clone(),
             spec_store: self.spec_store.clone(),
+            console_capture: self.console_capture.clone(),
         }
     }
 }
@@ -565,6 +588,7 @@ impl Statsig {
                 log_level,
                 value,
                 metadata,
+                None,
             ),
         });
     }
@@ -742,6 +766,8 @@ impl Statsig {
         parameter_store_name: &str,
         options: ParameterStoreEvaluationOptions,
     ) -> ParameterStore<'_> {
+        let store_name_intern = InternedString::from_str_ref(parameter_store_name);
+
         self.event_logger
             .increment_non_exposure_checks(parameter_store_name);
 
@@ -764,7 +790,7 @@ impl Statsig {
 
         let stores = &data.values.param_stores;
         let store = match stores {
-            Some(stores) => stores.get(parameter_store_name),
+            Some(stores) => stores.get(&store_name_intern),
             None => {
                 return ParameterStore {
                     name: parameter_store_name.to_string(),
@@ -850,6 +876,7 @@ impl Statsig {
             &data,
             data.values.app_id.as_ref(),
             self.override_adapter.as_ref(),
+            true,
         );
         get_cmab_ranked_list(&mut context, cmab_name)
     }
@@ -862,7 +889,7 @@ impl Statsig {
     ) {
         let user_internal = self.internalize_user(user);
 
-        let mut experiment = self.get_experiment_impl(&user_internal, cmab_name);
+        let mut experiment = self.get_experiment_impl(&user_internal, cmab_name, None);
         experiment.rule_id = group_id;
 
         self.event_logger.enqueue(EnqueueExperimentExpoOp {
@@ -962,102 +989,33 @@ impl Statsig {
 
 impl Statsig {
     pub fn get_feature_gate_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        data.values.feature_gates.unperformant_keys()
+        self.spec_store
+            .unperformant_keys_entity_filter("feature_gates", "feature_gate")
     }
 
     pub fn get_dynamic_config_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        data.values
-            .dynamic_configs
-            .unperformant_keys_entity_filter("dynamic_config")
+        self.spec_store
+            .unperformant_keys_entity_filter("dynamic_configs", "dynamic_config")
     }
 
     pub fn get_experiment_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        data.values
-            .dynamic_configs
-            .unperformant_keys_entity_filter("experiment")
+        self.spec_store
+            .unperformant_keys_entity_filter("dynamic_configs", "experiment")
     }
 
     pub fn get_autotune_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        data.values
-            .dynamic_configs
-            .unperformant_keys_entity_filter("autotune")
+        self.spec_store
+            .unperformant_keys_entity_filter("dynamic_configs", "autotune")
     }
 
     pub fn get_parameter_store_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        match &data.values.param_stores {
-            Some(param_stores) => param_stores.keys().cloned().collect(),
-            None => vec![],
-        }
+        self.spec_store
+            .unperformant_keys_entity_filter("param_stores", "*")
     }
 
     pub fn get_layer_list(&self) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        data.values.layer_configs.unperformant_keys()
+        self.spec_store
+            .unperformant_keys_entity_filter("layer_configs", "*")
     }
 
     pub fn __get_parsed_user_agent_value(
@@ -1083,7 +1041,11 @@ impl Statsig {
     ) -> bool {
         let user_internal = self.internalize_user(user);
         let disable_exposure_logging = options.disable_exposure_logging;
-        let (details, evaluation) = self.get_gate_evaluation(&user_internal, gate_name);
+        let (details, evaluation) = self.get_gate_evaluation(
+            &user_internal,
+            gate_name,
+            Some(options.disable_exposure_logging),
+        );
 
         let value = evaluation.as_ref().map(|e| e.value).unwrap_or_default();
         let rule_id = evaluation
@@ -1122,7 +1084,11 @@ impl Statsig {
     ) -> FeatureGate {
         let user_internal = self.internalize_user(user);
         let disable_exposure_logging = options.disable_exposure_logging;
-        let (details, evaluation) = self.get_gate_evaluation(&user_internal, gate_name);
+        let (details, evaluation) = self.get_gate_evaluation(
+            &user_internal,
+            gate_name,
+            Some(options.disable_exposure_logging),
+        );
 
         if disable_exposure_logging {
             log_d!(TAG, "Exposure logging is disabled for gate {}", gate_name);
@@ -1144,38 +1110,24 @@ impl Statsig {
     }
 
     pub fn manually_log_gate_exposure(&self, user: &StatsigUser, gate_name: &str) {
+        let interned_gate_name = InternedString::from_str_ref(gate_name);
         let user_internal = self.internalize_user(user);
-        let (details, evaluation) = self.get_gate_evaluation(&user_internal, gate_name);
-        self.event_logger.enqueue(EnqueueGateExpoOp {
-            exposure_time: Utc::now().timestamp_millis() as u64,
-            user: &user_internal,
-            queried_gate_name: gate_name,
-            evaluation: evaluation.map(Cow::Owned),
-            details: details.clone(),
-            trigger: ExposureTrigger::Manual,
-        });
+
+        let (details, evaluation) =
+            self.evaluate_spec_raw(&user_internal, gate_name, &SpecType::Gate, None);
+
+        self.event_logger.enqueue(EnqueueExposureOp::gate_exposure(
+            &user_internal,
+            &interned_gate_name,
+            ExposureTrigger::Manual,
+            details,
+            evaluation,
+        ));
     }
 
     pub fn get_fields_needed_for_gate(&self, gate_name: &str) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                self.ops_stats.clone(),
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        let gate = data.values.feature_gates.get(gate_name);
-        match gate {
-            Some(gate) => match &gate.spec.fields_used {
-                Some(fields) => fields.iter().map(|f| f.unperformant_to_string()).collect(),
-                None => vec![],
-            },
-            None => vec![],
-        }
+        self.spec_store
+            .get_fields_used_for_entity(gate_name, SpecType::Gate)
     }
 }
 
@@ -1202,7 +1154,11 @@ impl Statsig {
     ) -> DynamicConfig {
         let user_internal = self.internalize_user(user);
         let disable_exposure_logging = options.disable_exposure_logging;
-        let dynamic_config = self.get_dynamic_config_impl(&user_internal, dynamic_config_name);
+        let dynamic_config = self.get_dynamic_config_impl(
+            &user_internal,
+            dynamic_config_name,
+            Some(options.disable_exposure_logging),
+        );
 
         if disable_exposure_logging {
             log_d!(
@@ -1231,36 +1187,29 @@ impl Statsig {
         user: &StatsigUser,
         dynamic_config_name: &str,
     ) {
+        let interned_dynamic_config_name = InternedString::from_str_ref(dynamic_config_name);
         let user_internal = self.internalize_user(user);
-        let dynamic_config = self.get_dynamic_config_impl(&user_internal, dynamic_config_name);
-        self.event_logger.enqueue(EnqueueConfigExpoOp {
-            exposure_time: Utc::now().timestamp_millis() as u64,
-            user: &user_internal,
-            config: &dynamic_config,
-            trigger: ExposureTrigger::Manual,
-        });
+
+        let (details, evaluation) = self.evaluate_spec_raw(
+            &user_internal,
+            dynamic_config_name,
+            &SpecType::DynamicConfig,
+            None,
+        );
+
+        self.event_logger
+            .enqueue(EnqueueExposureOp::dynamic_config_exposure(
+                &user_internal,
+                &interned_dynamic_config_name,
+                ExposureTrigger::Manual,
+                details,
+                evaluation,
+            ));
     }
 
     pub fn get_fields_needed_for_dynamic_config(&self, config_name: &str) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                self.ops_stats.clone(),
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        let config = data.values.dynamic_configs.get(config_name);
-        match config {
-            Some(config) => match &config.spec.fields_used {
-                Some(fields) => fields.iter().map(|f| f.unperformant_to_string()).collect(),
-                None => vec![],
-            },
-            None => vec![],
-        }
+        self.spec_store
+            .get_fields_used_for_entity(config_name, SpecType::DynamicConfig)
     }
 }
 
@@ -1283,7 +1232,11 @@ impl Statsig {
     ) -> Experiment {
         let user_internal = self.internalize_user(user);
         let disable_exposure_logging = options.disable_exposure_logging;
-        let mut experiment = self.get_experiment_impl(&user_internal, experiment_name);
+        let mut experiment = self.get_experiment_impl(
+            &user_internal,
+            experiment_name,
+            Some(options.disable_exposure_logging),
+        );
         if let Some(persisted_experiment) = self.persistent_values_manager.as_ref().and_then(|m| {
             m.try_apply_sticky_value_to_experiment(&user_internal, &options, &experiment)
         }) {
@@ -1313,36 +1266,24 @@ impl Statsig {
     }
 
     pub fn manually_log_experiment_exposure(&self, user: &StatsigUser, experiment_name: &str) {
+        let interned_experiment_name = InternedString::from_str_ref(experiment_name);
         let user_internal = self.internalize_user(user);
-        let experiment = self.get_experiment_impl(&user_internal, experiment_name);
-        self.event_logger.enqueue(EnqueueExperimentExpoOp {
-            exposure_time: Utc::now().timestamp_millis() as u64,
-            user: &user_internal,
-            experiment: &experiment,
-            trigger: ExposureTrigger::Manual,
-        });
+        let (details, evaluation) =
+            self.evaluate_spec_raw(&user_internal, experiment_name, &SpecType::Experiment, None);
+
+        self.event_logger
+            .enqueue(EnqueueExposureOp::experiment_exposure(
+                &user_internal,
+                &interned_experiment_name,
+                ExposureTrigger::Manual,
+                details,
+                evaluation,
+            ));
     }
 
     pub fn get_fields_needed_for_experiment(&self, experiment_name: &str) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                self.ops_stats.clone(),
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        let config = data.values.dynamic_configs.get(experiment_name);
-        match config {
-            Some(config) => match &config.spec.fields_used {
-                Some(fields) => fields.iter().map(|f| f.unperformant_to_string()).collect(),
-                None => vec![],
-            },
-            None => vec![],
-        }
+        self.spec_store
+            .get_fields_used_for_entity(experiment_name, SpecType::Experiment)
     }
 
     pub fn get_experiment_by_group_name(
@@ -1365,9 +1306,12 @@ impl Statsig {
             );
         });
 
-        let Some(exp) = data.values.dynamic_configs.get(experiment_name) else {
+        let experiment_name = InternedString::from_str_ref(experiment_name);
+        let experiment = data.values.dynamic_configs.get(&experiment_name);
+
+        let Some(exp) = experiment else {
             return make_experiment(
-                experiment_name,
+                experiment_name.as_str(),
                 None,
                 EvaluationDetails::unrecognized(
                     &data.source,
@@ -1378,7 +1322,7 @@ impl Statsig {
         };
 
         if let Some(rule) = exp
-            .spec
+            .inner
             .rules
             .iter()
             .find(|rule| rule.group_name.as_deref() == Some(group_name))
@@ -1399,13 +1343,13 @@ impl Statsig {
                     data.values.time,
                     data.time_received_at,
                 ),
-                is_experiment_active: exp.spec.is_active.unwrap_or(false),
+                is_experiment_active: exp.inner.is_active.unwrap_or(false),
                 __evaluation: None,
             };
         }
 
         make_experiment(
-            experiment_name,
+            experiment_name.as_str(),
             None,
             EvaluationDetails::unrecognized(&data.source, data.values.time, data.time_received_at),
         )
@@ -1435,39 +1379,26 @@ impl Statsig {
         layer_name: &str,
         parameter_name: String,
     ) {
+        let interned_layer_name = InternedString::from_str_ref(layer_name);
+        let interned_parameter_name = InternedString::from_string(parameter_name);
         let user_internal = self.internalize_user(user);
-        let layer =
-            self.get_layer_impl(user_internal, layer_name, LayerEvaluationOptions::default());
+        let (details, evaluation) =
+            self.evaluate_spec_raw(&user_internal, layer_name, &SpecType::Layer, None);
 
         self.event_logger
-            .enqueue(EnqueueLayerParamExpoOp::LayerOwned(
-                Utc::now().timestamp_millis() as u64,
-                Box::new(layer),
-                parameter_name,
+            .enqueue(EnqueueExposureOp::layer_param_exposure(
+                &user_internal,
+                &interned_layer_name,
+                interned_parameter_name,
                 ExposureTrigger::Manual,
+                details,
+                evaluation,
             ));
     }
 
     pub fn get_fields_needed_for_layer(&self, layer_name: &str) -> Vec<String> {
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                self.ops_stats.clone(),
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return vec![];
-        });
-
-        let layer = data.values.layer_configs.get(layer_name);
-        match layer {
-            Some(layer) => match &layer.spec.fields_used {
-                Some(fields) => fields.iter().map(|f| f.unperformant_to_string()).collect(),
-                None => vec![],
-            },
-            None => vec![],
-        }
+        self.spec_store
+            .get_fields_used_for_entity(layer_name, SpecType::Layer)
     }
 }
 
@@ -1778,6 +1709,7 @@ impl Statsig {
         data: &'a SpecStoreData,
         app_id: Option<&'a DynamicValue>,
         override_adapter: Option<&'a Arc<dyn OverrideAdapter>>,
+        disable_exposure_logging: bool,
     ) -> EvaluatorContext<'a> {
         EvaluatorContext::new(
             user_internal,
@@ -1787,6 +1719,8 @@ impl Statsig {
             app_id,
             override_adapter,
             self.should_user_third_party_parser(),
+            Some(self),
+            disable_exposure_logging,
         )
     }
 
@@ -1810,9 +1744,51 @@ impl Statsig {
             app_id,
             override_adapter,
             self.should_user_third_party_parser(),
+            None,
+            true,
         )
     }
 
+    fn evaluate_spec_raw(
+        &self,
+        user_internal: &StatsigUserInternal,
+        spec_name: &str,
+        spec_type: &SpecType,
+        disable_exposure_logging: Option<bool>,
+    ) -> (EvaluationDetails, Option<EvaluatorResult>) {
+        let data = read_lock_or_else!(self.spec_store.data, {
+            log_error_to_statsig_and_console!(
+                &self.ops_stats,
+                TAG,
+                StatsigErr::LockFailure(
+                    "Failed to acquire read lock for spec store data".to_string()
+                )
+            );
+            return (EvaluationDetails::unrecognized_no_data(), None);
+        });
+
+        let mut context = self.create_standard_eval_context(
+            user_internal,
+            &data,
+            data.values.app_id.as_ref(),
+            self.override_adapter.as_ref(),
+            disable_exposure_logging.unwrap_or(false),
+        );
+
+        match Self::evaluate_with_details(&mut context, &data, spec_name, spec_type) {
+            Ok(eval_details) => (eval_details, Some(context.result)),
+            Err(e) => {
+                log_error_to_statsig_and_console!(
+                    &self.ops_stats,
+                    TAG,
+                    StatsigErr::EvaluationError(e.to_string())
+                );
+                (EvaluationDetails::error(&e.to_string()), None)
+            }
+        }
+    }
+
+    #[allow(clippy::too_many_arguments)]
     fn evaluate_spec<T>(
         &self,
         user_internal: &StatsigUserInternal,
@@ -1820,6 +1796,7 @@ impl Statsig {
         make_empty_result: impl FnOnce(EvaluationDetails) -> T,
         make_result: impl FnOnce(EvaluatorResult, EvaluationDetails) -> T,
         spec_type: &SpecType,
+        disable_exposure_logging: Option<bool>,
     ) -> T {
         let data = read_lock_or_else!(self.spec_store.data, {
             log_error_to_statsig_and_console!(
@@ -1837,6 +1814,7 @@ impl Statsig {
             &data,
             data.values.app_id.as_ref(),
             self.override_adapter.as_ref(),
+            disable_exposure_logging.unwrap_or(false),
         );
 
         match Self::evaluate_with_details(&mut context, &data, spec_name, spec_type) {
@@ -1907,6 +1885,7 @@ impl Statsig {
         &self,
         user_internal: &StatsigUserInternal,
         gate_name: &str,
+        disable_exposure_logging: Option<bool>,
     ) -> (EvaluationDetails, Option<GateEvaluation>) {
         self.evaluate_spec(
             user_internal,
@@ -1917,6 +1896,7 @@ impl Statsig {
                 (eval_details, Some(evaluation))
             },
             &SpecType::Gate,
+            disable_exposure_logging,
         )
     }
 
@@ -1924,6 +1904,7 @@ impl Statsig {
         &self,
         user_internal: &StatsigUserInternal,
         config_name: &str,
+        disable_exposure_logging: Option<bool>,
     ) -> DynamicConfig {
         self.evaluate_spec(
             user_internal,
@@ -1934,6 +1915,7 @@ impl Statsig {
                 make_dynamic_config(config_name, Some(evaluation), eval_details)
             },
             &SpecType::DynamicConfig,
+            disable_exposure_logging,
         )
     }
 
@@ -1941,6 +1923,7 @@ impl Statsig {
         &self,
         user_internal: &StatsigUserInternal,
         experiment_name: &str,
+        disable_exposure_logging: Option<bool>,
     ) -> Experiment {
         self.evaluate_spec(
             user_internal,
@@ -1951,6 +1934,7 @@ impl Statsig {
                 make_experiment(experiment_name, Some(evaluation), eval_details)
             },
             &SpecType::Experiment,
+            disable_exposure_logging,
         )
     }
 
@@ -1993,6 +1977,7 @@ impl Statsig {
                 )
             },
             &SpecType::Layer,
+            Some(evaluation_options.disable_exposure_logging),
         );
 
         let data = read_lock_or_else!(self.spec_store.data, {
@@ -2197,6 +2182,7 @@ fn setup_ops_stats(
     statsig_runtime: Arc<StatsigRuntime>,
     error_observer: &Arc<dyn OpsStatsEventObserver>,
     diagnostics_observer: &Arc<dyn OpsStatsEventObserver>,
+    console_capture_observer: &Arc<dyn OpsStatsEventObserver>,
     external_observer: &Option<Weak<dyn ObservabilityClient>>,
 ) -> Arc<OpsStatsForInstance> {
     let ops_stat = OPS_STATS.get_for_instance(sdk_key);
@@ -2205,7 +2191,10 @@ fn setup_ops_stats(
         statsig_runtime.clone(),
         Arc::downgrade(diagnostics_observer),
     );
-
+    ops_stat.subscribe(
+        statsig_runtime.clone(),
+        Arc::downgrade(console_capture_observer),
+    );
     if let Some(ob_client) = external_observer {
         if let Some(client) = ob_client.upgrade() {
             client.init();
