@@ -1,6 +1,7 @@
 use serde::ser::SerializeStruct;
 use serde::{Serialize, Serializer};
 
+use crate::console_capture::console_capture_options::ConsoleCaptureOptions;
 use crate::data_store_interface::DataStoreTrait;
 use crate::evaluation::dynamic_value::DynamicValue;
 use crate::event_logging_adapter::EventLoggingAdapter;
@@ -12,7 +13,7 @@ use crate::{
     log_d, log_w, serialize_if_not_none, ConfigCompressionMode, ObservabilityClient,
     OverrideAdapter, SpecAdapterConfig, SpecsAdapter,
 };
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
 use std::fmt;
 use std::sync::{Arc, Weak};
 
@@ -65,8 +66,12 @@ pub struct StatsigOptions {
 
     pub proxy_config: Option<ProxyConfig>,
 
+    pub console_capture_options: Option<ConsoleCaptureOptions>,
+
     pub use_third_party_ua_parser: Option<bool>,
     pub disable_disk_access: Option<bool>,
+
+    pub experimental_flags: Option<HashSet<String>>,
 }
 
 impl StatsigOptions {
@@ -113,6 +118,15 @@ impl StatsigOptionsBuilder {
         self
     }
 
+    #[must_use]
+    pub fn spec_adapters_config(
+        mut self,
+        spec_adapters_config: Option<Vec<SpecAdapterConfig>>,
+    ) -> Self {
+        self.inner.spec_adapters_config = spec_adapters_config;
+        self
+    }
+
     // Event Logging
 
     #[must_use]
