@@ -7,7 +7,7 @@ use statsig_rust::log_event_payload::{LogEventPayload, LogEventRequest};
 use statsig_rust::{EventLoggingAdapter, StatsigLocalFileEventLoggingAdapter};
 use std::fs;
 use std::sync::Arc;
-use utils::mock_scrapi::{Endpoint, EndpointStub, Method, MockScrapi};
+use utils::mock_scrapi::{Endpoint, EndpointStub, Method, MockScrapi, StubData};
 
 const SDK_KEY: &str = "server-local-file-events-test";
 const EVENTS_FILE_NAME: &str = "3776104929_events.json"; // djb2(SDK_KEY)_events.json
@@ -20,7 +20,7 @@ const SINGLE_EVENT_DATA: &str = r#"{
     "user":{
         "statsigEnvironment":null,"userID":"a-user"
     },
-    "value":"bar"
+    "value":"bar"   
 }"#;
 
 lazy_static! {
@@ -28,7 +28,7 @@ lazy_static! {
 }
 
 async fn setup(test_name: &str) -> (MockScrapi, String) {
-    let test_path = format!("/tmp/{}", test_name);
+    let test_path = format!("/tmp/{test_name}");
 
     if std::path::Path::new(&test_path).exists() {
         fs::remove_dir_all(&test_path).unwrap();
@@ -40,7 +40,7 @@ async fn setup(test_name: &str) -> (MockScrapi, String) {
     mock_scrapi
         .stub(EndpointStub {
             method: Method::POST,
-            response: "{\"success\": true}".to_string(),
+            response: StubData::String("{\"success\": true}".to_string()),
             ..EndpointStub::with_endpoint(Endpoint::LogEvent)
         })
         .await;
@@ -66,7 +66,7 @@ async fn test_writing_to_file() {
         .await
         .unwrap();
 
-    let out_path = format!("{}/{}", tmp_path, EVENTS_FILE_NAME);
+    let out_path = format!("{tmp_path}/{EVENTS_FILE_NAME}");
     assert_eventually!(|| std::path::Path::new(&out_path).exists());
 }
 
@@ -215,7 +215,7 @@ async fn test_sending_events_over_network() {
 
     adapter.send_pending_events().await.unwrap();
 
-    let out_path = format!("{}/{}", tmp_path, EVENTS_FILE_NAME);
+    let out_path = format!("{tmp_path}/{EVENTS_FILE_NAME}");
     assert_eventually!(|| fs::read_to_string(&out_path).unwrap().is_empty());
 }
 
